"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ini = require("ini");
const fs = require("fs");
function parseData(config, rawdata) {
    const data = rawdata ? ini.parse(rawdata) : {};
    let result = {};
    let errors = [];
    for (let C in config) {
        result[C] = {};
        for (let F in config[C]) {
            let gfieldConfig = config[C][F];
            let fieldConfig = ((gfieldConfig === Number || gfieldConfig === String || gfieldConfig === Boolean) ? { type: gfieldConfig } : gfieldConfig);
            const envname = `${C.toUpperCase()}_${F.toUpperCase()}`;
            let value = (data[C] || {})[F] || process.env[envname] || fieldConfig.default;
            if (!value && !fieldConfig.optional) {
                errors.push(`[${C}][${F}] Cannot be undefined!`);
            }
            else {
                switch (fieldConfig.type) {
                    case Number:
                        value = Number(value);
                        break;
                    case String:
                        value = String(value);
                        break;
                    case Boolean:
                        value = Boolean(value);
                        break;
                }
                result[C][F] = value;
            }
        }
    }
    if (errors.length > 0)
        throw new Error("There are errors: \n" + errors.join("\n"));
    return result;
}
function parse(config, path) {
    let data;
    if (path)
        data = fs.readFileSync(path).toString("utf8");
    return parseData(config, data);
}
exports.parse = parse;
async function parseAsync(config, path) {
    let data = await new Promise((yes, no) => fs.readFile(path, (err, data) => err ? no(err) : yes(data))).then(res => res.toString("utf8"));
    return parseData(config, data);
}
exports.parseAsync = parseAsync;
//# sourceMappingURL=index.js.map